@@ -25,7 +25,7 @@
 
 Combined1 = setClass(Class = "Combined1",
                      contains = "ModelError",
-                      representation = representation
+                     representation = representation
                      (
                        outcome="character",
                        equation = "expression",
@@ -38,39 +38,38 @@ Combined1 = setClass(Class = "Combined1",
                                             equation =  expression(sigmaInter + sigmaSlope * evaluationOutcome )
                      ))
 
-setMethod(
-  f="initialize",
-  signature="Combined1",
-  definition= function (.Object, outcome, equation, derivatives, sigmaInter, sigmaSlope, cError )
-  {
-    if(!missing(outcome))
-    {
-      .Object@outcome = outcome
-    }
-    if(!missing(equation))
-    {
-      .Object@equation = equation
-    }
-    if(!missing(derivatives))
-    {
-      .Object@derivatives = derivatives
-    }
-    if(!missing(sigmaInter))
-    {
-      .Object@sigmaInter = sigmaInter
-    }
-    if(!missing(sigmaSlope))
-    {
-      .Object@sigmaSlope = sigmaSlope
-    }
-    if( !missing( cError ) )
-    {
-      .Object@cError = cError
-    }
+setMethod( f="initialize",
+           signature="Combined1",
+           definition= function (.Object, outcome, equation, derivatives, sigmaInter, sigmaSlope, cError )
+           {
+             if(!missing(outcome))
+             {
+               .Object@outcome = outcome
+             }
+             if(!missing(equation))
+             {
+               .Object@equation = equation
+             }
+             if(!missing(derivatives))
+             {
+               .Object@derivatives = derivatives
+             }
+             if(!missing(sigmaInter))
+             {
+               .Object@sigmaInter = sigmaInter
+             }
+             if(!missing(sigmaSlope))
+             {
+               .Object@sigmaSlope = sigmaSlope
+             }
+             if( !missing( cError ) )
+             {
+               .Object@cError = cError
+             }
 
-    validObject(.Object)
-    return (.Object )
-  }
+             validObject(.Object)
+             return (.Object )
+           }
 )
 
 ##########################################################################################################
