@@ -33,48 +33,50 @@ Design = setClass("Design",
                     numberOfArms = "numeric",
                     fim = "Fim" ) )
 
-setMethod(
-  f="initialize",
-  signature="Design",
-  definition= function (.Object, name, size, arms, outcomesEvaluation, outcomesGradient, numberOfArms, fim )
-  {
-    if(!missing(name))
-    {
-      .Object@name = name
-    }
-    if(!missing(size))
-    {
-      .Object@size = size
-    }
-    if(!missing(arms))
-    {
-      .Object@arms = unlist(arms)
-    }
-    if(!missing(outcomesEvaluation))
-    {
-      .Object@outcomesEvaluation = outcomesEvaluation
-    }
-    if(!missing(outcomesGradient))
-    {
-      .Object@outcomesGradient = outcomesGradient
-    }
-    if(!missing(fim))
-    {
-      .Object@fim = fim
-    }
-    if(!missing(numberOfArms))
-    {
-      .Object@numberOfArms = numberOfArms
-    }
-    validObject(.Object)
-    return (.Object )
-  }
+setMethod(f="initialize",
+          signature="Design",
+          definition= function (.Object, name, size, arms, outcomesEvaluation, outcomesGradient, numberOfArms, fim )
+          {
+            if(!missing(name))
+            {
+              .Object@name = name
+            }
+            if(!missing(size))
+            {
+              .Object@size = size
+            }
+            if(!missing(arms))
+            {
+              .Object@arms = unlist(arms)
+            }
+            if(!missing(outcomesEvaluation))
+            {
+              .Object@outcomesEvaluation = outcomesEvaluation
+            }
+            if(!missing(outcomesGradient))
+            {
+              .Object@outcomesGradient = outcomesGradient
+            }
+            if(!missing(fim))
+            {
+              .Object@fim = fim
+            }
+            if(!missing(numberOfArms))
+            {
+              .Object@numberOfArms = numberOfArms
+            }
+            validObject(.Object)
+            return (.Object )
+          }
 )
 
 # ======================================================================================================
 # getName
 # ======================================================================================================
 
+#' @rdname getName
+#' @export
+
 setMethod(f="getName",
           signature="Design",
           definition = function(object)
@@ -86,6 +88,9 @@ setMethod(f="getName",
 # setName
 # ======================================================================================================
 
+#' @rdname setName
+#' @export
+
 setMethod(f="setName",
           signature="Design",
           definition = function(object, name)
@@ -98,6 +103,9 @@ setMethod(f="setName",
 # getSize
 # ======================================================================================================
 
+#' @rdname getSize
+#' @export
+
 setMethod(f="getSize",
           signature="Design",
           definition = function(object)
@@ -110,6 +118,9 @@ setMethod(f="getSize",
 # setSize
 # ======================================================================================================
 
+#' @rdname setSize
+#' @export
+
 setMethod(f="setSize",
           signature="Design",
           definition = function(object,size)
@@ -122,6 +133,9 @@ setMethod(f="setSize",
 # getArms
 # ======================================================================================================
 
+#' @rdname getArms
+#' @export
+
 setMethod(f="getArms",
           signature="Design",
           definition = function(object)
@@ -134,6 +148,9 @@ setMethod(f="getArms",
 # setArms
 # ======================================================================================================
 
+#' @rdname setArms
+#' @export
+
 setMethod(f="setArms",
           signature="Design",
           definition = function(object,arms)
@@ -143,13 +160,12 @@ setMethod(f="setArms",
           }
 )
 
-# ======================================================================================================
 #' Get the results of the evaluation of the outcomes.
 #'
-#' @name getOutcomesEvaluation
+#' @title getOutcomesEvaluation
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @return The list \code{outcomesEvaluation} containing the results of the design evaluation for the outcomes.
-# ======================================================================================================
+#' @export
 
 setGeneric("getOutcomesEvaluation",
            function(object)
@@ -158,6 +174,9 @@ setGeneric("getOutcomesEvaluation",
            }
 )
 
+#' @rdname getOutcomesEvaluation
+#' @export
+
 setMethod(f="getOutcomesEvaluation",
           signature="Design",
           definition = function(object)
@@ -166,14 +185,13 @@ setMethod(f="getOutcomesEvaluation",
           }
 )
 
-# ======================================================================================================
 #' Set the results of the evaluation of the outcomes.
 #'
-#' @name setOutcomesEvaluation
+#' @title setOutcomesEvaluation
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @param outcomesEvaluation A list containing the evaluation of the outcomes.
 #' @return An object \code{Design} with the list \code{outcomesEvaluation} updated.
-# ======================================================================================================
+#' @export
 
 setGeneric("setOutcomesEvaluation",
            function( object, outcomesEvaluation )
@@ -182,6 +200,9 @@ setGeneric("setOutcomesEvaluation",
            }
 )
 
+#' @rdname setOutcomesEvaluation
+#' @export
+
 setMethod(f="setOutcomesEvaluation",
           signature="Design",
           definition = function(object,outcomesEvaluation)
@@ -191,13 +212,12 @@ setMethod(f="setOutcomesEvaluation",
           }
 )
 
-# ======================================================================================================
 #' Get the results of the evaluation of the outcome gradients.
 #'
-#' @name getOutcomesGradient
+#' @title getOutcomesGradient
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @return  The list \code{outcomesGradient} containing the results of the design evaluation for the outcome gradients.
-# ======================================================================================================
+#' @export
 
 setGeneric("getOutcomesGradient",
            function(object)
@@ -206,7 +226,10 @@ setGeneric("getOutcomesGradient",
            }
 )
 
-setMethod(f="getOutcomesGradient",
+#' @rdname getFim
+#' @export
+
+setMethod(f="getFim",
           signature="Design",
           definition = function(object)
           {
@@ -214,14 +237,13 @@ setMethod(f="getOutcomesGradient",
           }
 )
 
-# ======================================================================================================
 #' Set the results of the evaluation of the outcomes.
 #'
-#' @name setOutcomesGradient
+#' @title setOutcomesGradient
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @param outcomesGradient A list containing the evaluation of the outcome gradients.
 #' @return An object \code{Design} with the list \code{outcomesGradient} updated.
-# ======================================================================================================
+#' @export
 
 setGeneric("setOutcomesGradient",
            function(object,outcomesGradient)
@@ -230,6 +252,9 @@ setGeneric("setOutcomesGradient",
            }
 )
 
+#' @rdname setOutcomesGradient
+#' @export
+
 setMethod(f="setOutcomesGradient",
           signature="Design",
           definition = function(object,outcomesGradient)
@@ -239,6 +264,9 @@ setMethod(f="setOutcomesGradient",
           }
 )
 
+#' @rdname getFim
+#' @export
+
 setMethod(f="getFim",
           signature="Design",
           definition = function(object)
@@ -247,14 +275,13 @@ setMethod(f="getFim",
           }
 )
 
-# ======================================================================================================
 #' Set the fim of the design.
 #'
-#' @name setFim
+#' @title setFim
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @param fim An object \code{fim} from the class \linkS4class{Fim}.
 #' @return An object \code{Design} with the \code{fim} updated.
-# ======================================================================================================
+#' @export
 
 setGeneric("setFim",
            function(object,fim)
@@ -263,6 +290,9 @@ setGeneric("setFim",
            }
 )
 
+#' @rdname setFim
+#' @export
+
 setMethod(f="setFim",
           signature="Design",
           definition = function(object,fim)
@@ -272,13 +302,12 @@ setMethod(f="setFim",
           }
 )
 
-# ======================================================================================================
 #' Get the number of arms in a design.
 #'
-#' @name getNumberOfArms
+#' @title getNumberOfArms
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @return A numeric \code{numberOfArms} giving the number of arms in the design.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getNumberOfArms",
@@ -286,6 +315,9 @@ setGeneric(
     standardGeneric("getNumberOfArms")
   })
 
+#' @rdname getNumberOfArms
+#' @export
+
 setMethod("getNumberOfArms",
           "Design",
           function( object )
@@ -294,14 +326,13 @@ setMethod("getNumberOfArms",
           }
 )
 
-# ======================================================================================================
 #' Set the number of arms in a design.
 #'
-#' @name setNumberOfArms
+#' @title setNumberOfArms
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @param numberOfArms A numeric \code{numberOfArms} giving the new number of arms in the design.
 #' @return An object \code{Design} with the \code{numberOfArms} updated.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setNumberOfArms",
@@ -309,6 +340,9 @@ setGeneric(
     standardGeneric("setNumberOfArms")
   })
 
+#' @rdname setNumberOfArms
+#' @export
+
 setMethod("setNumberOfArms",
           "Design",
           function( object, numberOfArms )
@@ -318,14 +352,13 @@ setMethod("setNumberOfArms",
           }
 )
 
-# ======================================================================================================
 #' Set the arms in a design.
 #'
-#' @name setArm
+#' @title setArm
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @param arm A list of object \code{Arm} giving the arms of the design.
 #' @return An object \code{Design} with the list \code{Arm} updated.
-# ======================================================================================================
+#' @export
 
 setGeneric("setArm",
            function( object, arm )
@@ -334,6 +367,9 @@ setGeneric("setArm",
            }
 )
 
+#' @rdname setArm
+#' @export
+
 setMethod(f="setArm",
           signature = "Design",
           definition = function( object, arm )
@@ -351,15 +387,14 @@ setMethod(f="setArm",
             return( object )
           })
 
-# ======================================================================================================
 #' Evaluate an design
 #'
-#' @name EvaluateDesign
+#' @title EvaluateDesign
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @param model An object \code{model} from the class \linkS4class{Model}.
 #' @param fim An object \code{fim} from the class \linkS4class{Fim}.
 #' @return The object \code{Design} with its slot \code{fim}, \code{evaluationOutcomes}, \code{outcomesGradient} updated.
-# ======================================================================================================
+#' @export
 
 setGeneric("EvaluateDesign",
            function( object, model, fim )
@@ -368,6 +403,9 @@ setGeneric("EvaluateDesign",
            }
 )
 
+#' @rdname EvaluateDesign
+#' @export
+
 setMethod(f="EvaluateDesign",
           signature = "Design",
           definition = function( object, model, fim )
@@ -423,16 +461,15 @@ setMethod(f="EvaluateDesign",
             return( object )
           })
 
-# ======================================================================================================
 #' Plot the evaluation of the outcomes.
 #'
-#' @name plotOutcomesEvaluation
+#' @title plotOutcomesEvaluation
 #' @param object An object \code{Design} from the class \linkS4class{Design}.
 #' @param initialDesign An object \code{design} from the class \linkS4class{Design}.
 #' @param model An object \code{model} from the class \linkS4class{Model}.
 #' @param plotOptions A list containing the plot options.
 #' @return A list containing the plots the evaluation of the outcomes.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "plotOutcomesEvaluation",
@@ -440,6 +477,9 @@ setGeneric(
     standardGeneric("plotOutcomesEvaluation")
   })
 
+#' @rdname plotOutcomesEvaluation
+#' @export
+
 setMethod(f="plotOutcomesEvaluation",
           signature("Design"),
           function( object, initialDesign, model, plotOptions ){
@@ -529,16 +569,15 @@ setMethod(f="plotOutcomesEvaluation",
             return( plotOutcome )
           })
 
-# ======================================================================================================
 #' Plot the evaluation of the outcome gradients.
 #'
-#' @name plotOutcomesGradient
+#' @title plotOutcomesGradient
 #' @param object An object \code{design} from the class \linkS4class{Design}.
 #' @param initialDesign An object \code{design} from the class \linkS4class{Design}.
 #' @param model An object \code{model} from the class \linkS4class{Model}.
 #' @param plotOptions A list containing the plot options.
 #' @return A list containing the plots the evaluation of the outcome gradients..
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "plotOutcomesGradient",
@@ -546,6 +585,9 @@ setGeneric(
     standardGeneric("plotOutcomesGradient")
   })
 
+#' @rdname plotOutcomesGradient
+#' @export
+
 setMethod(f="plotOutcomesGradient",
           signature("Design"),
           function( object, initialDesign, model, plotOptions ){
@@ -642,9 +684,11 @@ setMethod(f="plotOutcomesGradient",
             return( plotOutcome )
           })
 
-# ======================================================================================================
-# show
-# ======================================================================================================
+
+#' @title show
+#' @rdname show
+#' @param object object
+#' @export
 
 setMethod(f="show",
           signature="Design",
@@ -697,13 +741,12 @@ setMethod(f="show",
           }
 )
 
-# ======================================================================================================
 #' Generate table for the report.
 #'
-#' @name reportTablesSamplingConstraints
+#' @title reportTablesSamplingConstraints
 #' @param object An object \code{design} from the class \linkS4class{Design}.
 #' @return A table of the sampling constraints parameters for the report.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "reportTablesSamplingConstraints",
@@ -711,6 +754,9 @@ setGeneric(
     standardGeneric("reportTablesSamplingConstraints")
   })
 
+#' @rdname reportTablesSamplingConstraints
+#' @export
+
 setMethod("reportTablesSamplingConstraints",
           signature("Design"),
           function( object )
@@ -809,13 +855,12 @@ setMethod("reportTablesSamplingConstraints",
             return( listSamplingConstraints )
           })
 
-# ======================================================================================================
 #' Generate table for the report.
 #'
-#' @name reportTablesAdministration
+#' @title reportTablesAdministration
 #' @param object An object \code{design} from the class \linkS4class{Design}.
 #' @return A table of the administration parameters for the report.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "reportTablesAdministration",
@@ -823,6 +868,9 @@ setGeneric(
     standardGeneric("reportTablesAdministration")
   })
 
+#' @rdname reportTablesAdministration
+#' @export
+
 setMethod("reportTablesAdministration",
           signature("Design"),
           function( object )
@@ -883,13 +931,12 @@ setMethod("reportTablesAdministration",
 
           })
 
-# ======================================================================================================
 #' Generate table for the report.
 #'
-#' @name reportTablesDesign
+#' @title reportTablesDesign
 #' @param object An object \code{design} from the class \linkS4class{Design}.
 #' @return A table of the design parameters for the report.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "reportTablesDesign",
@@ -897,6 +944,9 @@ setGeneric(
     standardGeneric("reportTablesDesign")
   })
 
+#' @rdname reportTablesDesign
+#' @export
+
 setMethod("reportTablesDesign",
           signature("Design"),
           function( object )
@@ -954,13 +1004,12 @@ setMethod("reportTablesDesign",
             return( designTable )
           })
 
-# ==========================================================
 #' Check the validity of he sampling times constraints
 #'
-#' @name checkValiditySamplingConstraint
+#' @title checkValiditySamplingConstraint
 #' @param object An object from the class \linkS4class{Design}.
 #' @return An error message if a constraint is not valid.
-# ==========================================================
+#' @export
 
 setGeneric("checkValiditySamplingConstraint",
            function( object  )
@@ -969,6 +1018,9 @@ setGeneric("checkValiditySamplingConstraint",
            }
 )
 
+#' @rdname checkValiditySamplingConstraint
+#' @export
+
 setMethod(f="checkValiditySamplingConstraint",
           signature = "Design",
           definition = function( object )
@@ -1054,13 +1106,12 @@ setMethod(f="checkValiditySamplingConstraint",
             }
           })
 
-# ===============================================================================
 #' Set the sampling times constraint for optimization with PSO, PGBO and Simplex
 #'
-#' @name setSamplingConstraintForOptimization
+#' @title setSamplingConstraintForOptimization
 #' @param object An object from the class \linkS4class{Design}.
 #' @return The arms with the sampling times constraints.
-# ===============================================================================
+#' @export
 
 setGeneric("setSamplingConstraintForOptimization",
            function( object )
@@ -1069,6 +1120,9 @@ setGeneric("setSamplingConstraintForOptimization",
            }
 )
 
+#' @rdname setSamplingConstraintForOptimization
+#' @export
+
 setMethod(f="setSamplingConstraintForOptimization",
           signature = "Design",
           definition = function( object  )
