@@ -40,62 +40,64 @@ Model = setClass("Model",
                    odeSolverParameters = "list",
                    modelFromLibrary = "list"))
 
-setMethod(
-  f="initialize",
-  signature="Model",
-  definition= function (.Object, name, description, equations, outcomes, outcomesForEvaluation, parameters,
-                        modelError, initialConditions, odeSolverParameters,modelFromLibrary )
-  {
-    if(!missing(name))
-    {
-      .Object@name = name
-    }
-    if(!missing( description ) )
-    {
-      .Object@description = description
-    }
-    if(!missing( equations ) )
-    {
-      .Object@equations = equations
-    }
-    if(!missing( outcomes ) )
-    {
-      .Object@outcomes = outcomes
-    }
-    if(!missing( outcomesForEvaluation ) )
-    {
-      .Object@outcomesForEvaluation = outcomesForEvaluation
-    }
-    if(!missing( parameters ) )
-    {
-      .Object@parameters = parameters
-    }
-    if(!missing( initialConditions ) )
-    {
-      .Object@initialConditions = initialConditions
-    }
-    if(!missing( modelError ) )
-    {
-      .Object@modelError = modelError
-    }
-    if(!missing( odeSolverParameters ) )
-    {
-      .Object@odeSolverParameters = odeSolverParameters
-    }
-    if(!missing( modelFromLibrary ) )
-    {
-      .Object@modelFromLibrary = modelFromLibrary
-    }
+setMethod( f="initialize",
+           signature="Model",
+           definition= function (.Object, name, description, equations, outcomes, outcomesForEvaluation, parameters,
+                                 modelError, initialConditions, odeSolverParameters,modelFromLibrary )
+           {
+             if(!missing(name))
+             {
+               .Object@name = name
+             }
+             if(!missing( description ) )
+             {
+               .Object@description = description
+             }
+             if(!missing( equations ) )
+             {
+               .Object@equations = equations
+             }
+             if(!missing( outcomes ) )
+             {
+               .Object@outcomes = outcomes
+             }
+             if(!missing( outcomesForEvaluation ) )
+             {
+               .Object@outcomesForEvaluation = outcomesForEvaluation
+             }
+             if(!missing( parameters ) )
+             {
+               .Object@parameters = parameters
+             }
+             if(!missing( initialConditions ) )
+             {
+               .Object@initialConditions = initialConditions
+             }
+             if(!missing( modelError ) )
+             {
+               .Object@modelError = modelError
+             }
+             if(!missing( odeSolverParameters ) )
+             {
+               .Object@odeSolverParameters = odeSolverParameters
+             }
+             if(!missing( modelFromLibrary ) )
+             {
+               .Object@modelFromLibrary = modelFromLibrary
+             }
 
-    validObject(.Object)
-    return (.Object )
-  }
+             validObject(.Object)
+             return (.Object )
+           }
 )
 
 # ======================================================================================================
 # getName
 # ======================================================================================================
 
+#' @rdname getName
+#' @export
+
 setMethod("getName",
           "Model",
           function(object) {
@@ -106,6 +108,9 @@ setMethod("getName",
 # setName
 # ======================================================================================================
 
+#' @rdname setName
+#' @export
+
 setMethod("setName",
           "Model",
           function(object, name) {
@@ -113,13 +118,12 @@ setMethod("setName",
             return( object )
           })
 
-# ======================================================================================================
 #' Get the description of a model.
 #'
 #' @name getDescription
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A list giving the description of a model.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getDescription",
@@ -127,20 +131,22 @@ setGeneric(
     standardGeneric("getDescription")
   })
 
+#' @rdname getDescription
+#' @export
+
 setMethod("getDescription",
           "Model",
           function(object) {
             return( object@description )
           })
 
-# ======================================================================================================
 #' Set the description of a model.
 #'
 #' @name setDescription
 #' @param object An object from the class \linkS4class{Model}.
 #' @param description A list giving the description of a model.
 #' @return The model with the updated description.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setDescription",
@@ -148,6 +154,9 @@ setGeneric(
     standardGeneric("setDescription")
   })
 
+#' @rdname setDescription
+#' @export
+
 setMethod("setDescription",
           "Model",
           function(object, description) {
@@ -155,13 +164,12 @@ setMethod("setDescription",
             return( object )
           })
 
-# ======================================================================================================
 #' Get the equations of a model.
 #'
 #' @name getEquations
 #' @param object An object from the class \linkS4class{Model}.
 #' @return The list giving the equations of the model.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getEquations",
@@ -169,20 +177,22 @@ setGeneric(
     standardGeneric("getEquations")
   })
 
+#' @rdname getEquations
+#' @export
+
 setMethod("getEquations",
           "Model",
           function(object) {
             return( object@equations )
           })
 
-# ======================================================================================================
 #' Set the equations of a model.
 #'
 #' @name setEquations
 #' @param object An object from the class \linkS4class{Model}.
 #' @param equations A list giving the equations of the model.
 #' @return The model with the updated equations.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setEquations",
@@ -190,6 +200,9 @@ setGeneric(
     standardGeneric("setEquations")
   })
 
+#' @rdname setEquations
+#' @export
+
 setMethod("setEquations",
           "Model",
           function(object,equations) {
@@ -203,14 +216,13 @@ setMethod("setEquations",
             return( object )
           })
 
-# ======================================================================================================
 #' Set  a model from the library of model
 #'
 #' @name setModelFromLibrary
 #' @param object An object from the class \linkS4class{Model}.
 #' @param modelFromLibrary An object from the class \linkS4class{Model}.
 #' @return The model with the updated model from library of models.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setModelFromLibrary",
@@ -218,6 +230,9 @@ setGeneric(
     standardGeneric("setModelFromLibrary")
   })
 
+#' @rdname setModelFromLibrary
+#' @export
+
 setMethod("setModelFromLibrary",
           "Model",
           function( object, modelFromLibrary ) {
@@ -231,13 +246,13 @@ setMethod("setModelFromLibrary",
             return( object )
           })
 
-# ======================================================================================================
+
 #' Get the outcomes of a model.
 #'
 #' @name getOutcomes
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A list giving the outcomes of the model.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getOutcomes",
@@ -245,20 +260,22 @@ setGeneric(
     standardGeneric("getOutcomes")
   })
 
+#' @rdname getOutcomes
+#' @export
+
 setMethod("getOutcomes",
           "Model",
           function(object) {
             return( object@outcomes )
           })
 
-# ======================================================================================================
 #' Set the outcomes of a model.
 #'
 #' @name setOutcomes
 #' @param object An object from the class \linkS4class{Model}.
 #' @param outcomes A list giving the outcomes of the model.
 #' @return The model with the updated outcomes.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setOutcomes",
@@ -266,6 +283,9 @@ setGeneric(
     standardGeneric("setOutcomes")
   })
 
+#' @rdname setOutcomes
+#' @export
+
 setMethod("setOutcomes",
           "Model",
           function(object,outcomes) {
@@ -285,13 +305,12 @@ setMethod("setOutcomes",
             return( object )
           })
 
-# ======================================================================================================
 #' Get the outcomes of a model used for the evaluation (is scales outcomes).
 #'
 #' @name getOutcomesForEvaluation
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A list giving the outcomes of a model used for the evaluation (is scales outcomes).
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getOutcomesForEvaluation",
@@ -299,20 +318,22 @@ setGeneric(
     standardGeneric("getOutcomesForEvaluation")
   })
 
+#' @rdname getOutcomesForEvaluation
+#' @export
+
 setMethod("getOutcomesForEvaluation",
           "Model",
           function(object) {
             return( object@outcomesForEvaluation )
           })
 
-# ======================================================================================================
 #' Set the outcomes of a model used for the evaluation (is scales outcomes).
 #'
 #' @name setOutcomesForEvaluation
 #' @param object An object from the class \linkS4class{Model}.
 #' @param outcomes A list giving the outcomes of a model used for the evaluation (is scales outcomes).
 #' @return The model with the updated outcomes for the evaluation.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setOutcomesForEvaluation",
@@ -320,6 +341,9 @@ setGeneric(
     standardGeneric("setOutcomesForEvaluation")
   })
 
+#' @rdname setOutcomesForEvaluation
+#' @export
+
 setMethod("setOutcomesForEvaluation",
           "Model",
           function(object,outcomes) {
@@ -331,6 +355,9 @@ setMethod("setOutcomesForEvaluation",
 # getParameters
 # ======================================================================================================
 
+#' @rdname getParameters
+#' @export
+
 setMethod("getParameters",
           "Model",
           function(object) {
@@ -341,6 +368,9 @@ setMethod("getParameters",
 # setParameters
 # ======================================================================================================
 
+#' @rdname setParameters
+#' @export
+
 setMethod("setParameters",
           "Model",
           function(object,parameters) {
@@ -352,20 +382,22 @@ setMethod("setParameters",
 # getModelError
 # ======================================================================================================
 
+#' @rdname getModelError
+#' @export
+
 setMethod("getModelError",
           "Model",
           function(object) {
             return( object@modelError )
           })
 
-# ======================================================================================================
 #' Set the model error.
 #'
 #' @name setModelError
 #' @param object An object from the class \linkS4class{Model}.
 #' @param modelError  An object from the class \linkS4class{ModelError}.
 #' @return The model with the updated model error.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "setModelError",
@@ -373,6 +405,9 @@ setGeneric(
     standardGeneric("setModelError")
   })
 
+#' @rdname setModelError
+#' @export
+
 setMethod("setModelError",
           "Model",
           function(object, modelError ) {
@@ -384,30 +419,18 @@ setMethod("setModelError",
 # getInitialConditions
 # ======================================================================================================
 
+#' @rdname getInitialConditions
+#' @export
+
 setMethod("getInitialConditions",
           "Model",
           function(object) {
             return( object@initialConditions )
           })
 
-# ======================================================================================================
-#' Set the initial conditions of a ode model.
-#'
-#' @name setInitialConditions
-#' @param object An object from the class \linkS4class{Model}.
-#' @param initialConditions A list giving the initial conditions.
-#' @return The model with the updated initial conditions.
-# ======================================================================================================
 
-setGeneric(
-  "setInitialConditions",
-  function(object, initialConditions) {
-    standardGeneric("setInitialConditions")
-  })
-
-# ======================================================================================================
-# setInitialConditions
-# ======================================================================================================
+#' @rdname setInitialConditions
+#' @export
 
 setMethod("setInitialConditions",
           "Model",
@@ -420,20 +443,22 @@ setMethod("setInitialConditions",
 # getOdeSolverParameters
 # ======================================================================================================
 
+#' @rdname getOdeSolverParameters
+#' @export
+
 setMethod("getOdeSolverParameters",
           "Model",
           function(object) {
             return( object@odeSolverParameters )
           })
 
-# ======================================================================================================
 #' Set the parameters of the ode solver.
 #'
 #' @name setOdeSolverParameters
 #' @param object An object from the class \linkS4class{Model}.
 #' @param odeSolverParameters A list giving the parameters of the ode solver.
 #' @return The model with the updated parameters of the ode solver.
-# ======================================================================================================
+#' @export
 
 setGeneric("setOdeSolverParameters",
            function(object,odeSolverParameters)
@@ -441,6 +466,9 @@ setGeneric("setOdeSolverParameters",
              standardGeneric("setOdeSolverParameters")
            })
 
+#' @rdname setOdeSolverParameters
+#' @export
+
 setMethod("setOdeSolverParameters",
           "Model",
           function(object,odeSolverParameters) {
@@ -448,13 +476,12 @@ setMethod("setOdeSolverParameters",
             return( object )
           })
 
-# ======================================================================================================
 #' Get a model from the library of models.
 #'
 #' @name getModelFromLibrary
 #' @param object An object from the class \linkS4class{Model}.
 #' @return Return a model from the the library of models.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getModelFromLibrary",
@@ -462,19 +489,21 @@ setGeneric(
     standardGeneric("getModelFromLibrary")
   })
 
+#' @rdname getModelFromLibrary
+#' @export
+
 setMethod("getModelFromLibrary",
           "Model",
           function(object) {
             return( object@modelFromLibrary )
           })
 
-# ======================================================================================================
 #' Convert an analytic model to a ode model.
 #'
 #' @name convertPKModelAnalyticToPKModelODE
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A ode model.
-# ======================================================================================================
+#' @export
 
 setGeneric("convertPKModelAnalyticToPKModelODE",
            function( object )
@@ -482,13 +511,12 @@ setGeneric("convertPKModelAnalyticToPKModelODE",
              standardGeneric("convertPKModelAnalyticToPKModelODE")
            })
 
-# ======================================================================================================
 #' Get the number of parameters.
 #'
 #' @name getNumberOfParameters
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A numeric giving the number of parameters of the model.
-# ======================================================================================================
+#' @export
 
 setGeneric("getNumberOfParameters",
            function(object)
@@ -496,6 +524,9 @@ setGeneric("getNumberOfParameters",
              standardGeneric("getNumberOfParameters")
            })
 
+#' @rdname getNumberOfParameters
+#' @export
+
 setMethod("getNumberOfParameters",
           signature("Model"),
           function(object)
@@ -503,13 +534,12 @@ setMethod("getNumberOfParameters",
             return(length(object@parameters))
           })
 
-# ======================================================================================================
 #' Test if a mode is ode.
 #'
 #' @name isModelODE
 #' @param object An object from the class \linkS4class{Model}.
 #' @return Return a Boolean giving if the mode is ode or not.
-# ======================================================================================================
+#' @export
 
 setGeneric("isModelODE",
            function(object)
@@ -517,6 +547,9 @@ setGeneric("isModelODE",
              standardGeneric("isModelODE")
            })
 
+#' @rdname isModelODE
+#' @export
+
 setMethod(f="isModelODE",
           signature="Model",
           definition = function(object)
@@ -526,13 +559,12 @@ setMethod(f="isModelODE",
             return(isModelODE)
           })
 
-# ======================================================================================================
 #' Test if a mode is analytic.
 #'
 #' @name isModelAnalytic
 #' @param object An object from the class \linkS4class{Model}.
 #' @return Return a Boolean giving if the mode is analytic or not.
-# ======================================================================================================
+#' @export
 
 setGeneric("isModelAnalytic",
            function(object)
@@ -540,6 +572,9 @@ setGeneric("isModelAnalytic",
              standardGeneric("isModelAnalytic")
            })
 
+#' @rdname isModelAnalytic
+#' @export
+
 setMethod(f="isModelAnalytic",
           signature="Model",
           definition = function(object)
@@ -549,13 +584,12 @@ setMethod(f="isModelAnalytic",
             return(isModelAnalytic)
           })
 
-# ======================================================================================================
 #' Test if the dose is in the equations of the model.
 #'
 #' @name isDoseInEquations
 #' @param object An object from the class \linkS4class{Model}.
 #' @return Return a Boolean giving if the dose is in the equations of the model.
-# ======================================================================================================
+#' @export
 
 setGeneric("isDoseInEquations",
            function(object)
@@ -563,6 +597,9 @@ setGeneric("isDoseInEquations",
              standardGeneric("isDoseInEquations")
            })
 
+#' @rdname isDoseInEquations
+#' @export
+
 setMethod(f="isDoseInEquations",
           signature="Model",
           definition = function(object)
@@ -572,13 +609,12 @@ setMethod(f="isDoseInEquations",
             return(isDoseInEquations)
           })
 
-# ======================================================================================================
 #' Test if a mode is infusion
 #'
 #' @name isModelInfusion
 #' @param object An object from the class \linkS4class{Model}.
 #' @return Return a Boolean giving if the mode is infusion or not.
-# ======================================================================================================
+#' @export
 
 setGeneric("isModelInfusion",
            function(object)
@@ -586,6 +622,9 @@ setGeneric("isModelInfusion",
              standardGeneric("isModelInfusion")
            })
 
+#' @rdname isModelInfusion
+#' @export
+
 setMethod(f="isModelInfusion",
           signature="Model",
           definition = function(object)
@@ -595,13 +634,12 @@ setMethod(f="isModelInfusion",
             return(isInfusion)
           })
 
-# ======================================================================================================
 #' Test if a mode is steady state.
 #'
 #' @name isModelSteadyState
 #' @param object An object from the class \linkS4class{Model}.
 #' @return Return a Boolean giving if the mode is steady state or not.
-# ======================================================================================================
+#' @export
 
 setGeneric("isModelSteadyState",
            function(object)
@@ -609,6 +647,9 @@ setGeneric("isModelSteadyState",
              standardGeneric("isModelSteadyState")
            })
 
+#' @rdname isModelSteadyState
+#' @export
+
 setMethod(f="isModelSteadyState",
           signature="Model",
           definition = function(object)
@@ -618,14 +659,13 @@ setMethod(f="isModelSteadyState",
             return(isSteadyState)
           })
 
-# ======================================================================================================
 #' Test if a mode is bolus.
 #'
 #' @name isModelBolus
 #' @param object An object from the class \linkS4class{Model}.
 #' @param designs A list of objects from the class \linkS4class{Design}.
 #' @return Return a Boolean giving if the mode is bolus or not.
-# ======================================================================================================
+#' @export
 
 setGeneric("isModelBolus",
            function( object, designs )
@@ -633,6 +673,9 @@ setGeneric("isModelBolus",
              standardGeneric("isModelBolus")
            })
 
+#' @rdname isModelBolus
+#' @export
+
 setMethod(f="isModelBolus",
           signature = "Model",
           definition = function( object, designs )
@@ -645,7 +688,6 @@ setMethod(f="isModelBolus",
             return(isModelBolus)
           })
 
-# ======================================================================================================
 #' Define a PKPD model.
 #'
 #' @name definePKPDModel
@@ -653,7 +695,7 @@ setMethod(f="isModelBolus",
 #' @param PDModel An object from the class \linkS4class{Model}.
 #' @param outcomes A list giving the outcomes of the  PKPD model.
 #' @return A model giving a PKPD model.
-# ======================================================================================================
+#' @export
 
 setGeneric("definePKPDModel",
            function( PKModel, PDModel, outcomes )
@@ -661,14 +703,13 @@ setGeneric("definePKPDModel",
              standardGeneric("definePKPDModel")
            })
 
-# ======================================================================================================
 #' Define a PK model.
 #'
 #' @name definePKModel
 #' @param object An object from the class \linkS4class{Model}.
 #' @param outcomes A list giving the outcomes of the  PK model.
 #' @return A model giving a PK model.
-# ======================================================================================================
+#' @export
 
 setGeneric("definePKModel",
            function( object, outcomes )
@@ -676,14 +717,13 @@ setGeneric("definePKModel",
              standardGeneric("definePKModel")
            })
 
-# ======================================================================================================
 #' Define a model.
 #'
 #' @name defineModel
 #' @param object An object from the class \linkS4class{Model}.
 #' @param designs A list of objects from the class \linkS4class{Design}.
 #' @return A model defined either from the library of models or user defined.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "defineModel",
@@ -691,6 +731,9 @@ setGeneric(
     standardGeneric("defineModel")
   })
 
+#' @rdname defineModel
+#' @export
+
 setMethod("defineModel",
           "Model",
           function(object, designs) {
@@ -720,14 +763,13 @@ setMethod("defineModel",
             return( object )
           })
 
-# ======================================================================================================
 #' Define a model from the library of models.
 #'
 #' @name defineModelFromLibraryOfModels
 #' @param object An object from the class \linkS4class{Model}.
 #' @param designs A list of objects from the class \linkS4class{Design}.
 #' @return A model defined from the library of models.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "defineModelFromLibraryOfModels",
@@ -736,6 +778,9 @@ setGeneric(
     standardGeneric("defineModelFromLibraryOfModels")
   })
 
+#' @rdname defineModelFromLibraryOfModels
+#' @export
+
 setMethod(f = "defineModelFromLibraryOfModels",
           signature="Model",
           definition= function( object, designs )
@@ -791,14 +836,13 @@ setMethod(f = "defineModelFromLibraryOfModels",
             return( model )
           })
 
-# ======================================================================================================
 #' Define a user defined model.
 #'
 #' @name defineModelUserDefined
 #' @param object An object from the class \linkS4class{Model}.
 #' @param designs A list of objects from the class \linkS4class{Design}.
 #' @return A model giving a user defined model.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "defineModelUserDefined",
@@ -806,6 +850,9 @@ setGeneric(
     standardGeneric("defineModelUserDefined")
   })
 
+#' @rdname defineModelUserDefined
+#' @export
+
 setMethod(f = "defineModelUserDefined",
           signature="Model",
           definition= function( object, designs )
@@ -864,14 +911,13 @@ setMethod(f = "defineModelUserDefined",
             return( newModel )
           })
 
-# ======================================================================================================
 #' Define the type of a model.
 #'
 #' @name defineModelType
 #' @param object An object from the class \linkS4class{Model}.
 #' @param designs A list of objects from the class \linkS4class{Design}.
 #' @return Return a model defined as analytic, ode, etc.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "defineModelType",
@@ -880,6 +926,9 @@ setGeneric(
     standardGeneric("defineModelType")
   })
 
+#' @rdname defineModelType
+#' @export
+
 setMethod(f = "defineModelType",
           signature="Model",
           definition= function(object, designs)
@@ -959,14 +1008,13 @@ setMethod(f = "defineModelType",
             return( newModel )
           })
 
-# ======================================================================================================
 #' Evaluate a model.
 #'
 #' @name EvaluateModel
 #' @param object An object from the class \linkS4class{Model}.
 #' @param arm An object from the class \linkS4class{Arm}.
 #' @return A list giving the results of the model evaluation.
-# ======================================================================================================
+#' @export
 
 setGeneric("EvaluateModel",
            function( object, arm )
@@ -974,13 +1022,12 @@ setGeneric("EvaluateModel",
              standardGeneric("EvaluateModel")
            })
 
-# ======================================================================================================
 #' Define the parameters for computing the gradients of a model.
 #'
 #' @name parametersForComputingGradient
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A list giving the parameters for computing the gradients of a model.
-# ======================================================================================================
+#' @export
 
 setGeneric("parametersForComputingGradient",
            function(object)
@@ -989,6 +1036,9 @@ setGeneric("parametersForComputingGradient",
            }
 )
 
+#' @rdname parametersForComputingGradient
+#' @export
+
 setMethod(f = "parametersForComputingGradient",
           signature="Model",
           definition= function(object)
@@ -1030,7 +1080,6 @@ setMethod(f = "parametersForComputingGradient",
             return( list( Xcols = Xcols, shifted = shifted, frac = frac ) )
           })
 
-# ======================================================================================================
 #' Evaluate the variance of a model.
 #'
 #' @name EvaluateVarianceModel
@@ -1038,7 +1087,7 @@ setMethod(f = "parametersForComputingGradient",
 #' @param arm An object from the class \linkS4class{Arm}.
 #' @param evaluationModel A list giving the outputs of the model evaluation.
 #' @return Return a list giving the results of the evaluation of the model variance.
-# ======================================================================================================
+#' @export
 
 setGeneric("EvaluateVarianceModel",
            function( object, arm, evaluationModel )
@@ -1047,6 +1096,9 @@ setGeneric("EvaluateVarianceModel",
            }
 )
 
+#' @rdname EvaluateVarianceModel
+#' @export
+
 setMethod(f = "EvaluateVarianceModel",
           signature="Model",
           definition= function(object, arm, evaluationModel )
@@ -1109,13 +1161,12 @@ setMethod(f = "EvaluateVarianceModel",
 
           })
 
-# ======================================================================================================
 #' Get the fixed parameters.
 #'
 #' @name getFixedParameters
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A list giving the fixed parameters of the model.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getFixedParameters",
@@ -1123,6 +1174,9 @@ setGeneric(
     standardGeneric("getFixedParameters")
   })
 
+#' @rdname getFixedParameters
+#' @export
+
 setMethod("getFixedParameters",
           signature("Model"),
           function(object)
@@ -1171,13 +1225,12 @@ setMethod("getFixedParameters",
 
           })
 
-# ======================================================================================================
 #' Get the values of the model error parameters.
 #'
 #' @name getModelErrorParametersValues
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A list giving the values of the model error parameters.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getModelErrorParametersValues",
@@ -1185,6 +1238,9 @@ setGeneric(
     standardGeneric("getModelErrorParametersValues")
   })
 
+#' @rdname getModelErrorParametersValues
+#' @export
+
 setMethod("getModelErrorParametersValues",
           signature("Model"),
           function(object)
@@ -1205,13 +1261,12 @@ setMethod("getModelErrorParametersValues",
             return(sigmaInterSlope)
           })
 
-# ======================================================================================================
 #' Get the values of the model parameters.
 #'
 #' @name getModelParametersValues
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A list giving the values of the model parameters.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "getModelParametersValues",
@@ -1219,6 +1274,9 @@ setGeneric(
     standardGeneric("getModelParametersValues")
   })
 
+#' @rdname getModelParametersValues
+#' @export
+
 setMethod("getModelParametersValues",
           signature("Model"),
           function(object)
@@ -1237,13 +1295,12 @@ setMethod("getModelParametersValues",
             return( modelParametersValues = list( mu = mu, omega = omega ) )
           })
 
-# ======================================================================================================
 #' Generate the tables for model parameters for the evaluation report.
 #'
 #' @name reportTablesModelParameters
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A kable table for the evaluation report.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "reportTablesModelParameters",
@@ -1251,6 +1308,9 @@ setGeneric(
     standardGeneric("reportTablesModelParameters")
   })
 
+#' @rdname reportTablesModelParameters
+#' @export
+
 setMethod("reportTablesModelParameters",
           signature("Model"),
           function(object)
@@ -1312,13 +1372,12 @@ setMethod("reportTablesModelParameters",
             return( tableParameters )
           })
 
-# ======================================================================================================
 #' Generate the tables for model errors for the evaluation report.
 #'
 #' @name reportTablesModelError
 #' @param object An object from the class \linkS4class{Model}.
 #' @return A kable table for the evaluation report.
-# ======================================================================================================
+#' @export
 
 setGeneric(
   "reportTablesModelError",
@@ -1326,6 +1385,9 @@ setGeneric(
     standardGeneric("reportTablesModelError")
   })
 
+#' @rdname reportTablesModelError
+#' @export
+
 setMethod("reportTablesModelError",
           signature("Model"),
           function( object )
