@@ -15,45 +15,47 @@ ModelAnalyticSteadyState = setClass("ModelAnalyticSteadyState",
                                       initialConditions = list(NULL),
                                       odeSolverParameters = list(NULL)))
 
-setMethod(
-  f="initialize",
-  signature="ModelAnalyticSteadyState",
-  definition= function (.Object, name, description, equations, outcomes, parameters, modelError )
-  {
-    if(!missing(name))
-    {
-      .Object@name = name
-    }
-    if(!missing(description))
-    {
-      .Object@description = description
-    }
-    if(!missing(equations))
-    {
-      .Object@equations = equations
-    }
-    if(!missing(outcomes))
-    {
-      .Object@outcomes = outcomes
-    }
-    if(!missing(parameters))
-    {
-      .Object@parameters = parameters
-    }
-    if(!missing(modelError))
-    {
-      .Object@modelError = modelError
-    }
+setMethod( f="initialize",
+           signature="ModelAnalyticSteadyState",
+           definition= function (.Object, name, description, equations, outcomes, parameters, modelError )
+           {
+             if(!missing(name))
+             {
+               .Object@name = name
+             }
+             if(!missing(description))
+             {
+               .Object@description = description
+             }
+             if(!missing(equations))
+             {
+               .Object@equations = equations
+             }
+             if(!missing(outcomes))
+             {
+               .Object@outcomes = outcomes
+             }
+             if(!missing(parameters))
+             {
+               .Object@parameters = parameters
+             }
+             if(!missing(modelError))
+             {
+               .Object@modelError = modelError
+             }
 
-    validObject(.Object)
-    return (.Object )
-  }
+             validObject(.Object)
+             return (.Object )
+           }
 )
 
 # ======================================================================================================
 # EvaluateModel
 # ======================================================================================================
 
+#' @rdname EvaluateModel
+#' @export
+
 setMethod(f = "EvaluateModel",
           signature = "ModelAnalyticSteadyState",
           definition = function( object, arm )
@@ -457,6 +459,9 @@ setMethod(f = "EvaluateModel",
 # definePKModel
 # ======================================================================================================
 
+#' @rdname definePKModel
+#' @export
+
 setMethod("definePKModel",
           signature("ModelAnalyticSteadyState"),
           definition = function( object, outcomes )
@@ -560,6 +565,9 @@ setMethod("definePKModel",
 # definePKPDModel
 # ======================================================================================================
 
+#' @rdname definePKPDModel
+#' @export
+
 setMethod("definePKPDModel",
           signature("ModelAnalyticSteadyState","ModelAnalyticSteadyState"),
           function( PKModel, PDModel, outcomes )
@@ -671,6 +679,9 @@ setMethod("definePKPDModel",
 # definePKPDModel
 # ======================================================================================================
 
+#' @rdname definePKPDModel
+#' @export
+
 setMethod("definePKPDModel",
           signature("ModelAnalyticSteadyState","ModelODE"),
           function( PKModel, PDModel, outcomes )
@@ -849,6 +860,9 @@ setMethod("definePKPDModel",
 # convertPKModelAnalyticToPKModelODE
 # ======================================================================================================
 
+#' @rdname convertPKModelAnalyticToPKModelODE
+#' @export
+
 setMethod("convertPKModelAnalyticToPKModelODE",
           signature("ModelAnalyticSteadyState"),
           function( object )
