@@ -10,30 +10,32 @@
 #' @export
 
 Normal = setClass( Class = "Normal",
-                     contains = "Distribution",
-                     representation = representation())
+                   contains = "Distribution",
+                   representation = representation())
 
-setMethod(
-  f = "initialize",
-  signature = "Normal",
-  definition = function( .Object, ... )
-  {
-    parameters = list(...)
+setMethod( f = "initialize",
+           signature = "Normal",
+           definition = function( .Object, ... )
+           {
+             parameters = list(...)
 
-    if(!missing(parameters))
-    {
-      .Object@parameters = list(mu = parameters$mu,
-                                omega = parameters$omega)
-    }
+             if(!missing(parameters))
+             {
+               .Object@parameters = list(mu = parameters$mu,
+                                         omega = parameters$omega)
+             }
 
-    validObject(.Object)
-    return (.Object )
-  })
+             validObject(.Object)
+             return (.Object )
+           })
 
 # ======================================================================================================
 # getAdjustedGradient
 # ======================================================================================================
 
+#' @rdname getAdjustedGradient
+#' @export
+
 setMethod("getAdjustedGradient",
           "Normal",
           function( object, outcomesGradient )
